package javax.swing.text.html;

import java.awt.Insets;
import java.awt.Graphics;
import java.awt.Color;
import javax.swing.border.LineBorder;
import javax.swing.text.AttributeSet;
import javax.swing.text.SimpleAttributeSet;
import java.awt.Font;
import javax.swing.text.Document;
import java.awt.Container;
import javax.swing.text.StyledDocument;
import javax.swing.JTextArea;
import javax.swing.text.JTextComponent;
import java.awt.Component;
import javax.swing.text.Element;
import javax.swing.border.Border;

class CommentView extends HiddenTagView
{
    static final Border CBorder;
    static final int commentPadding = 3;
    static final int commentPaddingD = 9;
    
    CommentView(Element element) {
        super(element);
    }
    
    @Override
    protected Component createComponent() {
        Container container = this.getContainer();
        if (container != null && !((JTextComponent)container).isEditable()) {
            return null;
        }
        JTextArea textArea = new JTextArea(this.getRepresentedText());
        Document document = this.getDocument();
        Font font;
        if ((document instanceof StyledDocument)) {
            font = ((StyledDocument)document).getFont(this.getAttributes());
            textArea.setFont(font);
        }
        else {
            font = textArea.getFont();
        }
        this.updateYAlign(font);
        textArea.setBorder(CommentView.CBorder);
        textArea.getDocument().addDocumentListener(this);
        textArea.setFocusable(this.isVisible());
        return textArea;
    }
    
    @Override
    void resetBorder() {
    }
    
    @Override
    void _updateModelFromText() {
        JTextComponent textComponent = this.getTextComponent();
        Document document = this.getDocument();
        if (textComponent != null && document != null) {
            String text = textComponent.getText();
            SimpleAttributeSet set = new SimpleAttributeSet();
            this.isSettingAttributes = true;
            try {
                set.addAttribute(HTML.Attribute.COMMENT, text);
                ((StyledDocument)document).setCharacterAttributes(this.getStartOffset(), this.getEndOffset() - this.getStartOffset(), set, false);
            }
            finally {
                this.isSettingAttributes = false;
            }
        }
    }
    
    @Override
    JTextComponent getTextComponent() {
        return (JTextComponent)this.getComponent();
    }
    
    @Override
    String getRepresentedText() {
        AttributeSet attributes = this.getElement().getAttributes();
        if (attributes != null) {
            Object attribute = attributes.getAttribute(HTML.Attribute.COMMENT);
            if ((attribute instanceof String)) {
                return (String)attribute;
            }
        }
        return "";
    }
    
    static {
        CBorder = new CommentView.CommentBorder();
    }
    
    static class CommentBorder extends LineBorder
    {
        CommentBorder() {
            super(Color.black, 1);
        }
        
        @Override
        public void paintBorder(Component c, Graphics g, int n, int y, int n2, int height) {
            super.paintBorder(c, g, n + 3, y, n2 - 9, height);
        }
        
        @Override
        public Insets getBorderInsets(Component c, Insets insets) {
            Insets borderInsets = super.getBorderInsets(c, insets);
            borderInsets.left += 3;
            borderInsets.right += 3;
            return borderInsets;
        }
        
        @Override
        public boolean isBorderOpaque() {
            return false;
        }
    }
}
